package com.example.prapro2spring.controller;

import com.example.prapro2spring.model.Person;
import com.example.prapro2spring.dto.PersonDTO;
import com.example.prapro2spring.service.PersonService;
import com.example.prapro2spring.repository.PeopleRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/persons")
public class PersonController {

    @Autowired
    private PeopleRepository peopleRepository;
    @Autowired
    private PersonService personService;


    @GetMapping
    public List<Person> getAllPersons() {
        return peopleRepository.findAll();
    }

    @GetMapping("/{id}")
    public Person getPersonById(@PathVariable Integer id) {
        return peopleRepository.findById(id).orElse(null);
    }

    @PostMapping
    public PersonDTO createPerson(@RequestBody PersonDTO person) {
        person.setId(null);
        if(person.getBirthTimestamp() == null) {
            person.setBirthTimestamp(java.time.LocalDateTime.now());
        }
        return personService.save(person);
    }

    @PutMapping("/{id}")
    public PersonDTO updatePerson(@PathVariable Integer id, @RequestBody PersonDTO personDetails) {
        PersonDTO person = personService.findById(id).orElse(null);
        if (person != null) {
            person.setParent1(personDetails.getParent1());
            person.setParent2(personDetails.getParent2());
            person.setBirthTimestamp(personDetails.getBirthTimestamp());
            return personService.save(person);
        }
        return null;
    }

    @DeleteMapping("/{id}")
    public void deletePerson(@PathVariable Integer id) {
        peopleRepository.deleteById(id);
    }
}